import speech_recognition as sr
import argparse


def audioToText(n):
    filename = n
    # initialize the recognizer
    r = sr.Recognizer()
    # open the file
    with sr.AudioFile(filename) as source:
        # listen for the data (load audio to memory)
        audio_data = r.record(source)
        # recognize (convert from speech to text)
        text = r.recognize_google(audio_data)
        print(text)


# =================================================================
# Arg parsing
def main():
    parser = argparse.ArgumentParser(prog='gfg',
                                     description='This a voice modem testing script.')

    parser.add_argument('-file', default=False, help="Provide audio file name to convert to text", required=True)

    args = parser.parse_args()
    n = args.file

    if args.file:
        audioToText(n)


if __name__ == "__main__":
    main()



from setuptools import setup, find_packages

with open('requirements.txt') as f:
    requirements = f.readlines()

long_description = 'USRVoiceConverter'

setup(
    name='USRVoiceConverter',
    version='1.0.0',
    author='Abirami',
    author_email='abiramig1930@gmail.com',
    url='',
    description='Analog Voice Modem Testing',
    long_description=long_description,
    long_description_content_type="text/markdown",
    license='MIT',
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'VoiceConverter = USRVoiceConverter.VoiceConverter:main'
        ]
    },
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ),
    keywords='analog_modem',
    install_requires=requirements,
    zip_safe=False
)